summaryrefslogtreecommitdiff
path: root/web/share/js/kvm/main.js
diff options
context:
space:
mode:
Diffstat (limited to 'web/share/js/kvm/main.js')
-rw-r--r--web/share/js/kvm/main.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/web/share/js/kvm/main.js b/web/share/js/kvm/main.js
index 8ab47b2c..4c4b662b 100644
--- a/web/share/js/kvm/main.js
+++ b/web/share/js/kvm/main.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -33,7 +33,7 @@ import {Session} from "./session.js";
export function main() {
if (checkBrowser()) {
window.onbeforeunload = function(event) {
- let text = "Are you sure you want to close Pi-KVM session?";
+ let text = "Are you sure you want to close PiKVM session?";
event.returnValue = text;
return text;
};
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #